==> haskell-openssl-streams-1.2.2.0-17-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-openssl-streams.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: openssl-streams
version: 1.2.2.0
id: openssl-streams-1.2.2.0-H0zNyBbXVlw6NEapryKAI1
key: openssl-streams-1.2.2.0-H0zNyBbXVlw6NEapryKAI1
license: BSD-3-Clause
maintainer: Gregory Collins <greg@gregorycollins.net>
synopsis: OpenSSL network support for io-streams.
description:
    The openssl-streams library contains io-streams routines for secure
    networking using OpenSSL (by way of HsOpenSSL).
category: Network, IO-Streams
abi: 822eef3c37432f5c5c9aabf4a54f259e
exposed: True
exposed-modules:
    System.IO.Streams.SSL
import-dirs: /usr/lib/ghc-8.6.5/site-local/openssl-streams-1.2.2.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/openssl-streams-1.2.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/openssl-streams-1.2.2.0
hs-libraries: HSopenssl-streams-1.2.2.0-H0zNyBbXVlw6NEapryKAI1
depends:
    HsOpenSSL-0.11.4.16-7RfyZJwAYaPLvukdLJguyi base-4.12.0.0
    bytestring-0.10.8.2 io-streams-1.5.1.0-Jr5Q18rgJkN1NXr3uJxXfl
    network-2.8.0.0-xbHtkcSHJTFxVBp7aTame
haddock-interfaces: /usr/share/doc/haskell-openssl-streams/html/openssl-streams.haddock
haddock-html: /usr/share/doc/haskell-openssl-streams/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-openssl-streams-1.2.2.0-19-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-openssl-streams.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: openssl-streams
version: 1.2.2.0
id: openssl-streams-1.2.2.0-95JBiEtM5n814ll69zLdk3
key: openssl-streams-1.2.2.0-95JBiEtM5n814ll69zLdk3
license: BSD-3-Clause
maintainer: Gregory Collins <greg@gregorycollins.net>
synopsis: OpenSSL network support for io-streams.
description:
    The openssl-streams library contains io-streams routines for secure
    networking using OpenSSL (by way of HsOpenSSL).
category: Network, IO-Streams
abi: e8cdb902dbad79ab98d8618080d461f7
exposed: True
exposed-modules:
    System.IO.Streams.SSL
import-dirs: /usr/lib/ghc-8.6.5/site-local/openssl-streams-1.2.2.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/openssl-streams-1.2.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/openssl-streams-1.2.2.0
hs-libraries: HSopenssl-streams-1.2.2.0-95JBiEtM5n814ll69zLdk3
depends:
    HsOpenSSL-0.11.4.16-286z3fleDVvC6QIierEbG1 base-4.12.0.0
    bytestring-0.10.8.2 io-streams-1.5.1.0-ARrp9xtkjAMDJvKX3hLohn
    network-2.8.0.0-EWiez0ajBalJ2cORFP4yEt
haddock-interfaces: /usr/share/doc/haskell-openssl-streams/html/openssl-streams.haddock
haddock-html: /usr/share/doc/haskell-openssl-streams/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
